@@ -1,7 +1,7 @@
 package Galileo;
 use Mojo::Base 'Mojolicious';
 
-our $VERSION = '0.034';
+our $VERSION = '0.035';
 $VERSION = eval $VERSION;
 
 use File::Basename 'dirname';
@@ -48,6 +48,20 @@ sub load_config {
       extra_js => [],
       extra_static_paths => ['static'],
       sanitize => 1,
+      pagedown_extra_options => {
+        highlighter => 'highlight',
+        table_class => 'table table-striped',
+        extensions  => [qw/
+          tables
+          fenced_code_gfm
+          def_list
+          attr_list
+          footnotes
+          smartypants
+          strikethrough
+          newlines
+        /],
+      },
       secrets => [],
       upload_path => 'uploads',
     },
@@ -348,6 +362,10 @@ L<PageDown|http://code.google.com/p/pagedown/> (Markdown engine) - the version o
 
 =item * 
 
+L<PageDown Extra|https://github.com/jmcmanus/pagedown-extra> - Markdown Extra Plugins for Pagedown
+
+=item * 
+
 L<Bootstrap|http://twitter.github.com/bootstrap> - the beautiful CSS/JS library from Twitter
 
 =item * 
